# Changelog

All notable changes to this project will be documented in this file.

## v0.0.1

- Initial open source version.

## v0.0.2

- Fix GH Actions Release workflow.

## v0.0.3

- Downgrade Python required version to 3.11.
